# Mesh

```sh
automesh mesh --help
<!-- cmdrun automesh mesh --help -->
```

## Mesh Hex

```sh
automesh mesh hex --help
<!-- cmdrun automesh mesh hex --help -->
```

## Mesh Tri

```sh
automesh mesh tri --help
<!-- cmdrun automesh mesh tri --help -->
```

## Mesh Hex Smooth

```sh
automesh mesh hex smooth --help
<!-- cmdrun automesh mesh hex smooth --help -->
```

## Mesh Tri Smooth

```sh
automesh mesh tri smooth --help
<!-- cmdrun automesh mesh tri smooth --help -->
```
